[dragonegg] r182392 - Port debug info fixes from mainline.

Duncan Sands baldrick at free.fr
Tue May 21 09:12:40 PDT 2013


Author: baldrick
Date: Tue May 21 11:12:40 2013
New Revision: 182392

URL: http://llvm.org/viewvc/llvm-project?rev=182392&view=rev
Log:
Port debug info fixes from mainline.

Added:
    dragonegg/branches/release_33/test/compilator/local/ada/volatile_function.adb
      - copied unchanged from r182192, dragonegg/trunk/test/compilator/local/ada/volatile_function.adb
    dragonegg/branches/release_33/test/compilator/local/ada/volatile_function.ads
      - copied unchanged from r182192, dragonegg/trunk/test/compilator/local/ada/volatile_function.ads
    dragonegg/branches/release_33/test/compilator/local/c/typedef.c
      - copied unchanged from r182192, dragonegg/trunk/test/compilator/local/c/typedef.c
Modified:
    dragonegg/branches/release_33/   (props changed)
    dragonegg/branches/release_33/src/Debug.cpp

Propchange: dragonegg/branches/release_33/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue May 21 11:12:40 2013
@@ -1 +1 @@
-/dragonegg/trunk:181689-182103
+/dragonegg/trunk:181689-182192

Modified: dragonegg/branches/release_33/src/Debug.cpp
URL: http://llvm.org/viewvc/llvm-project/dragonegg/branches/release_33/src/Debug.cpp?rev=182392&r1=182391&r2=182392&view=diff
==============================================================================
--- dragonegg/branches/release_33/src/Debug.cpp (original)
+++ dragonegg/branches/release_33/src/Debug.cpp Tue May 21 11:12:40 2013
@@ -231,7 +231,7 @@ StringRef DebugInfo::getFunctionName(tre
 
 /// EmitFunctionStart - Constructs the debug code for entering a function.
 void DebugInfo::EmitFunctionStart(tree FnDecl, Function *Fn) {
-  DIType FNType = getOrCreateType(TREE_TYPE(FnDecl));
+  DIType FNType = getOrCreateType(TYPE_MAIN_VARIANT(TREE_TYPE(FnDecl)));
 
   unsigned lineno = CurLineNo;
 
@@ -844,7 +844,7 @@ DIType DebugInfo::createStructType(tree
   return RealDecl;
 }
 
-/// createVarinatType - Create variant type or return MainTy.
+/// createVariantType - Create variant type or return MainTy.
 DIType DebugInfo::createVariantType(tree type, DIType MainTy) {
 
   DIType Ty;
@@ -885,7 +885,7 @@ DIType DebugInfo::createVariantType(tree
     return Ty;
   }
 
   // If, for some reason, main type varaint type is seen then use it.
   return MainTy;
 }
 
@@ -885,7 +885,7 @@ DIType DebugInfo::createVariantType(tree
   }
 
-  // If, for some reason, main type varaint type is seen then use it.
+  // If, for some reason, main type variant type is seen then use it.
   return MainTy;
 }





More information about the llvm-commits mailing list